@@ -420,13 +420,13 @@ def gen_method_member(cls, path, conf):
     lst.append(gen_method_offset(path, conf))
 
     # pointed = gen_c_pointed(Arg(Int8, pointer=True), conf)
-    lst.extend(Ref_get_c_offset("offset",conf))
+    lst.extend(Ref_get_c_offset("offset", conf))
     pointed = gen_c_pointed(retarg, conf)
     lst.append(f" return {pointed};")
     # GPU not handled
-    #lst.append("  char *reloff_p = (char *) obj + offset;")
-    #lst.append("  int64_t  reloff= *(int64_t *) reloff_p;")
-    #lst.append("  return (void*) (reloff_p + reloff);")
+    # lst.append("  char *reloff_p = (char *) obj + offset;")
+    # lst.append("  int64_t  reloff= *(int64_t *) reloff_p;")
+    # lst.append("  return (void*) (reloff_p + reloff);")
     lst.append("}")
     return "\n".join(lst), kernel
 
@@ -443,28 +443,29 @@ def gen_method_switch(cls, path, conf, method):
         extra=method.args,
         ret=method.ret,
     )
-    refname=lasttype.__name__
+    refname = lasttype.__name__
 
     decl = gen_c_decl_from_kernel(kernel, conf)
     lst = [decl + "{"]
-    voidp=gen_pointer("void*",conf)
+    voidp = gen_pointer("void*", conf)
     lst.append(f"  {voidp} member = {refname}_member(obj);")
     lst.append(f"  switch ({refname}_typeid(obj)){{")
     for atype in lasttype._reftypes:
-        atname=atype.__name__
-        targs=[f"({atname}) member"]
+        atname = atype.__name__
+        targs = [f"({atname}) member"]
         for arg in kernel.args[1:]:
             targs.append(f"{arg.name}")
-        targs=','.join(targs)
-        lst.append(f"""\
+        targs = ",".join(targs)
+        lst.append(
+            f"""\
         #ifndef {refname.upper()}_SKIP_{atname.upper()}
         case {refname}_{atname}_t:
             return {atname}_{method.c_name}({targs});
             break;
         #endif"""
         )
-    lst.append ("  }")
-    lst.append ("  return 0;")
+    lst.append("  }")
+    lst.append("  return 0;")
     lst.append("}")
     return "\n".join(lst), kernel
 
